# bodhilib

Bodhilib is a pluggable and extensible LLM framework.

Currently the popular LLM framework tends to do everything by themselves, resulting in extraordinary bloat,
Bodhilib is built on top of a plugin architecture, with a very thin core implementing the most
critical LLM related operations. Rest of the features and variations are provided by plugins.
